#include "keymap_common.h"

/*
 * ,---------------.
 * |Fn0|Fn1|Fn2|Fn3|
 * |---------------|
 * |---------------|
 * |Num| F2| F5| P/|
 * |---------------|
 * | P7| P8| P9| P*|
 * |---------------|
 * | P4| P5| P6| P-|
 * |---------------|
 * | P1| P2| P3| P+|
 * |---------------|
 * | P0| 00| P.| PE|
 * |---------------|
 */
const uint8_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
   /* Keymap 0: Numpad */
   KEYMAP(
        FN0, FN1, FN2, FN3, \
        NLCK, BSPC, DEL, PSLS, \
        P7, P8, P9, PAST, \
        P4, P5, P6, PMNS, \
        P1, P2, P3, PPLS, \
        P0, COMM, PDOT, PENT),
  /* Keymap 1: Functions keys */
  KEYMAP(
        FN0, FN1, FN2, FN3, \
        ESC, CAPS, SLCK, PSCR, \
        F9,  F10, F11, F12, \
        F5,  F6,  F7,  F8, \
        F1,  F2,  F3,  F4, \
	    LCTL, LALT, LSFT, TAB),
  /* Keymap 2: Navigation */
  KEYMAP(
        FN0, FN1, FN2, FN3, \
        TRNS, TRNS, FN8, FN7, \
        PGUP, INS, PGDN,  FN6, \
        HOME,  UP,  END,  FN5, \
	    LEFT, DOWN, RGHT, FN4, \
	    LCTL, LALT, LSFT, TAB),
  /* Keymap 3: Media */
  KEYMAP(
        FN0, FN1, FN2, FN3, \
        CALC, WAKE, SLEP, PWR, \
        WSCH, WHOM, WFAV, MYCM, \
        MAIL, WREF, MSEL, MUTE, \
        WBAK, VOLU, WFWD, MSTP, \
	    MPRV, VOLD, MNXT, MPLY),
};

 /*
 * Macro definition
 */
enum macro_id {
	MCNC,
    MCUT,
	MCPY,
	MPST,
	MRDO
};

const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
    keyevent_t event = record->event;
    //uint8_t tap_count = record->tap_count;

    switch (id) {
        case MCNC:
            return (event.pressed ?
                    MACRO( D(LCTL), T(Z), U(LCTL), END ) :
                    MACRO( END ) );
        case MCUT:
            return (event.pressed ?
                    MACRO( D(LCTL), T(X), U(LCTL), END ) :
                    MACRO( END ) );
        case MCPY:
            return (event.pressed ?
                    MACRO( D(LCTL), T(C), U(LCTL), END ) :
                    MACRO( END ) );
        case MPST:
            return (event.pressed ?
                    MACRO( D(LCTL), T(V), U(LCTL), END ) :
                    MACRO( END ) );
        case MRDO:
            return (event.pressed ?
                    MACRO( D(LCTL), T(Y), U(LCTL), END ) :
                    MACRO( END ) );
    }
    return MACRO_NONE;
}

/*
 * Fn action definition
 */
const uint16_t PROGMEM fn_actions[] = {
    [0] = ACTION_DEFAULT_LAYER_SET(0),
    [1] = ACTION_DEFAULT_LAYER_SET(1),
    [2] = ACTION_DEFAULT_LAYER_SET(2),
    [3] = ACTION_DEFAULT_LAYER_SET(3),
    [4] = ACTION_MACRO(MCNC),
    [5] = ACTION_MACRO(MCUT),
    [6] = ACTION_MACRO(MCPY),
    [7] = ACTION_MACRO(MPST),
    [8] = ACTION_MACRO(MRDO),
};
